@@ -419,6 +419,13 @@ _vte_pango_x_draw_char(struct _vte_draw *draw,
 	return TRUE;
 }
 
+static gboolean
+_vte_pango_x_draw_has_char(struct _vte_draw *draw, gunichar c)
+{
+	return FALSE;
+}
+
+
 static void
 _vte_pango_x_draw_rectangle(struct _vte_draw *draw,
 			  gint x, gint y, gint width, gint height,
@@ -486,6 +493,7 @@ const struct _vte_draw_impl _vte_draw_pango_x = {
 	_vte_pango_x_get_using_fontconfig,
 	_vte_pango_x_draw_text,
 	_vte_pango_x_draw_char,
+	_vte_pango_x_draw_has_char,
 	_vte_pango_x_draw_rectangle,
 	_vte_pango_x_fill_rectangle,
 	_vte_pango_x_set_scroll,
