@@ -149,14 +149,15 @@ _vte_regex_compile(const char *pattern)
 
 	ret = g_slice_new(struct _vte_regex);
 
-	ret->pcre = pcre_compile(pattern, PCRE_UTF8, &err, &err_offset, NULL);
+	ret->pcre = pcre_compile(pattern, PCRE_UTF8|PCRE_NO_UTF8_CHECK,
+			&err, &err_offset, NULL);
 	if (ret->pcre == NULL) {
 		g_slice_free(struct _vte_regex, ret);
 		return NULL;
 	}
 
 	ret->extra = pcre_study(ret->pcre, 0, &err);
-	if (ret->extra == NULL) {
+	if (err != NULL) {
 		pcre_free(ret->pcre);
 		g_slice_free(struct _vte_regex, ret);
 		return NULL;
@@ -177,31 +178,30 @@ int
 _vte_regex_exec(struct _vte_regex *regex, const char *string,
 		gsize nmatch, struct _vte_regex_match *matches)
 {
-	int i, n_matches, *ovector, ovector_length, length;
+	int ret, *ovector, ovector_length, length;
+	gsize n, n_matches;
 
-	for (i = 0; i < nmatch; i++) {
-		matches[i].rm_so = -1;
-		matches[i].rm_eo = -1;
+	for (n = 0; n < nmatch; n++) {
+		matches[n].rm_so = -1;
+		matches[n].rm_eo = -1;
 	}
 
 	length = strlen(string);
 	ovector_length = 3 * (length + 1);
-	ovector = g_malloc(sizeof(int) * ovector_length);
+	ovector = g_new(int, ovector_length);
 
-	i = pcre_exec(regex->pcre, regex->extra, string, length,
+	ret = pcre_exec(regex->pcre, regex->extra, string, length,
 		      0, 0, ovector, ovector_length);
-
-	if (i < 0) {
+	if (ret < 0) {
 		g_free(ovector);
 		return -1;
 	}
 
-	n_matches = i;
-	while (i > 0) {
-		i--;
-		if (i < nmatch) {
-			matches[i].rm_so = ovector[i * 2];
-			matches[i].rm_eo = ovector[i * 2 + 1];
+	n = n_matches = ret;
+	while (n-- > 0) {
+		if (n < nmatch) {
+			matches[n].rm_so = ovector[n * 2];
+			matches[n].rm_eo = ovector[n * 2 + 1];
 		}
 	}
 	_vte_regex_sort_matches(matches, n_matches);
@@ -245,9 +245,9 @@ _vte_regex_exec(struct _vte_regex *regex, const char *string,
 		gsize nmatch, struct _vte_regex_match *matches)
 {
 	regmatch_t *posix_matches;
-	int i, ret;
+	guint i, ret;
 
-	posix_matches = g_malloc(nmatch * sizeof(regmatch_t));
+	posix_matches = g_new(regmatch_t, nmatch);
 	ret = regexec(&regex->posix_regex, string, nmatch, posix_matches, 0);
 	if (ret == 0) {
 		for (i = 0; i < nmatch; i++) {
